======================================
``psyclone.psyir.symbols.symboltable``
======================================

.. automodule:: psyclone.psyir.symbols.symboltable

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.symboltable
